import { cancel } from "./utils.js";
const queue = [];
const queueListeners = [];
export function clearQueue(start = 0, emitEvent = false) {
    queue.slice(start).forEach(({ setSpeechStatus }) => setSpeechStatus("stopped"));
    queue.length = 0;
    if (emitEvent)
        emit();
}
export function addToQueue(item, callback) {
    queue.push(item);
    emit(callback);
}
export function clearQueueHook() {
    cancel();
    clearQueue(1, true);
}
export function clearQueueUnload() {
    cancel();
    clearQueue(1);
}
export function dequeue(index = 0) {
    if (index === 0)
        cancel();
    else
        removeFromQueue(index);
}
export function emit(callback) {
    const utteranceQueue = queue.map(({ utterance }) => utterance);
    queueListeners.forEach((listener) => listener(utteranceQueue));
    callback === null || callback === void 0 ? void 0 : callback(utteranceQueue);
}
export function removeFromQueue(utterance, callback) {
    const index = typeof utterance === "number" ? utterance : queue.findIndex((item) => item.utterance === utterance);
    if (index === -1)
        return;
    const [item] = queue.splice(index, 1);
    if (item) {
        item.setSpeechStatus("stopped");
        emit(callback);
    }
}
export function speakFromQueue() {
    const item = queue[0];
    if (item)
        speechSynthesis.speak(item.utterance);
}
export function subscribe(callback) {
    queueListeners.push(callback);
    return () => {
        const index = queueListeners.indexOf(callback);
        if (index !== -1)
            queueListeners.splice(index, 1);
    };
}
